@@ -18,17 +18,23 @@ class BaseCracker:
     # 可选参数
     option_params = {}
     
+    # 需要删除的多余参数
+    delete_params = []
+    
     def __init__(
         self,    
         user_token: str = None,
-        developer_id: str = "",   
-        user_agent: str = "",
+        developer_id: str = None,   
+        user_agent: str = None,
+        cookies: dict = {},
         proxy: str = None, 
         timeout: int = 30,
         debug: bool = False,
         check_useful: bool = False,
         max_retry_times: int = 3,
-        internal_proxy=True,
+        internal=True,
+        internal_api=True,
+        show_ad=True,
         **kwargs
     ) -> None:
         """
@@ -40,34 +46,45 @@ class BaseCracker:
         :param debug: 是否开启 debug 模式
         :param check_useful: 检查破解是否成功
         :param max_retry_times: 最大重试次数
-        :param internal_proxy: 是否使用国内代理
+        :param internal: 是否使用国内代理
         """
+        if show_ad:
+            logger.debug("感谢选择 nocaptcha, 我们只做别人做不到的(手动狗头)~")
+            logger.debug("欢迎推荐注册, 官网地址: https://www.nocaptcha.io/")
         self.user_token = user_token
         if not self.user_token:
             raise Exception("缺少用户凭证")
         self.developer_id = developer_id
+        self.cookies = cookies
         self.user_agent = user_agent
         self.proxy = proxy
         self.timeout = timeout
         self.debug = debug
         self.check_useful = check_useful
-        self.retry_times = 0
         self.max_retry_times = max_retry_times
 
+        self.internal_api = internal_api
         self.wanda_args = {
-            "internal_proxy": internal_proxy
+            "internal": internal
         }
         for k in self.must_check_params:
-            v = kwargs.get(k)
-            setattr(self, k, v)
-            self.wanda_args.update({ k: v })
+            _v = kwargs.get(k)
+            if not hasattr(self, k) or getattr(self, k) is None:
+                setattr(self, k, _v)
+            if _v is not None:
+                self.wanda_args.update({ k: _v })
         for k, v in self.option_params.items():
             _v = kwargs.get(k, v)
             if not hasattr(self, k) or getattr(self, k) is None:
                 setattr(self, k, _v)
-            self.wanda_args.update({ k: _v })
+            if _v is not None:
+                self.wanda_args.update({ k: _v })
+        
+        for k in self.delete_params:
+            if k in self.wanda_args:
+                del self.wanda_args[k]
 
-        if not all(getattr(self, k) for k in self.must_check_params):
+        if any(getattr(self, k) is None for k in self.must_check_params):
            raise AttributeError("缺少参数, 请检查")
 
     def response(self, result: Any):
@@ -82,13 +99,29 @@ class BaseCracker:
         }
         if self.developer_id:
             headers["Developer-Id"] = self.developer_id
-        resp = requests.post(f"http://api.nocaptcha.io/api/wanda/{self.cracker_name}/{self.cracker_version}", headers=headers, json={
-            **self.wanda_args,
-            "user_agent": self.user_agent,
-            "proxy": self.proxy
-        }, timeout=self.timeout).json()
-        if self.debug:
-            logger.info(resp)
+        
+        if self.user_agent:
+            self.wanda_args["user_agent"] = self.user_agent
+        if self.cookies:
+            self.wanda_args["cookies"] = self.cookies
+        if self.proxy:
+            self.wanda_args["proxy"] = self.proxy
+
+        retry_times = 0        
+        resp = {}
+        while retry_times < self.max_retry_times:
+            try:
+                resp = requests.post(
+                    f"http://{'xn--fjqs46frol.com' if self.internal_api else 'api.nocaptcha.io' }/api/wanda/{self.cracker_name}/{self.cracker_version}", 
+                    headers=headers, json=self.wanda_args, timeout=self.timeout
+                ).json()
+                if self.debug:
+                    logger.info(resp)
+                break
+            except Exception as e:
+                if self.debug:
+                    logger.error(e)
+                retry_times += 1
         wanda_ret = resp.get("data")
         if not wanda_ret:
             if self.debug:
@@ -100,8 +133,8 @@ class BaseCracker:
                 if self.debug:
                     logger.success("crack success")
             else:
-                self.retry_times += 1
-                if self.retry_times < self.max_retry_times:
+                retry_times += 1
+                if retry_times < self.max_retry_times:
                     return self.crack()
                 else:
                     logger.error("crack fail")
